sampling
--------

.. role:: underline
    :class: underline

.. automodule:: sampling
  :members:
  :undoc-members:

.. container:: toggle

   .. container:: header

      :underline:`sampling.py`

   .. literalinclude:: ../../libensemble/gen_funcs/sampling.py
      :language: python
      :linenos:

persistent_uniform_sampling
---------------------------
.. automodule:: persistent_uniform_sampling
  :members:
  :undoc-members:

.. container:: toggle

   .. container:: header

      :underline:`persistent_uniform_sampling.py`

   .. literalinclude:: ../../libensemble/gen_funcs/persistent_uniform_sampling.py
      :language: python
      :linenos:
